Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type APIServerProxy ¶
type APIServerProxy struct {
// TraefikConfigFile is the path to the traefik configuration file.
// Note that this is only to stay backwards-compatible with the initial implementation of
// worker nodes that was using Traefik for proxying requests to the control plane.
// Only a subset of Traefik configuration flags are supported.
TraefikConfigFile string
// KubeconfigFile is the path to the kubeconfig file to use for updating the list of known apiservers.
// The known apiservers are retrieved from `kubectl get endpoints kubernetes`.
KubeconfigFile string
// RefreshCh is used to check for updates in the list of control plane nodes in the cluster.
RefreshCh <-chan time.Time
}
APIServerProxy is a TCP proxy that forwards requests to the API Servers of the cluster.
Click to show internal directories.
Click to hide internal directories.