package
Version:
v0.0.0-...-71cdb78
Opens a new window with list of versions in this module.
Published: Sep 12, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type MockCIDR struct {
CIDR string
}
MockCIDR is a mock net.Addr
Network implements net.Addr
String implements net.Addr
MockRunner is a mock implementation of CommandRunner context.
Run is a mock implementation of CommandRunner.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.